Handbook - Muscle System Head Mesodermal Cell
Description: WormAtlas: A database of behavioral and structural anatomy of Caenorhabditis elegans.
Keywords: Caenorhabditis, elegans, anatomy, hermaphrodite, worm, nematode

Home Handbooks Hermaphrodite Male Dauer Embryo Aging P. pacificus S. stercoralis Resources WormImage Slidable Worm WormWiring Hall Lab Anatomical Methods Glossary of Terms Movie Gallery Individual Neurons Neurons & Circuits Worm Literature Cell Identification Cell Lineages Cell List Sperm Gallery Digital Development DIC PharynxAtlas User Guides Abbreviations Color Codes Copyright and Use How to Cite Links WormBase WormBook CGC WormGUIDES CytoSHOW OpenWorm Nemanode CeNGEN C. elegans Natural Diversity Anatomy by DIC - by J. Yochem About Us Mission Statement Contact

MUSCLE SYSTEM HEAD MESODERMAL CELL Click pictures for new window with figure and legend, click again for high resolution image
1 Head Mesodermal Cell The head mesodermal cell (hmc) and its homolog originate from the embryonic MS lineage and are sisters of gonadal cells Z4 and Z1, respectively (HmcFIG 1; Sulston et al., 1983). This single cell in the head lies in the pseudocoelom on the dorsal posterior side of the pharynx (HmcFIG 2). In the embryo, the hmc and hmc homolog migrate circumferentially to the dorsal midline where they meet and align anterior–posteriorly. The more anteriorly located cell (hmc homolog) dies late in embryogenesis (HmcFIG 2). HmcFIG 1: Position of hmc in early embryo. A. Embryo, 430 minutes after first cleavage, left lateral plane of focus. B. Embryo, 430 minutes after first cleavage, left medial plane of focus. Based on Sulston et al., 1983. HmcFIG 2:Head mesodermal cell. A. Embryo, 430 minutes after first cell cleavage, left medial plane of focus. After they are born as sisters of Z1 and Z4 blast cells from MS lineage, the hmc and hmc homolog (dotted circles, ventral side of the embryo) migrate circumferentially (arrowed paths) to the dorsal side of the embryo. (Orange ovals) hmc and hmc homolog in their dorsal positions. The hmc homolog later goes through programmed cell death (marked with an X). B. Schematic drawing of the cross section of the adult hmc cell at the level of the pharynx grinder in the terminal bulb. Two circumferentially directed processes travel in the pseudocoelom around the pharynx to meet at the ventral midline and then merge. (Yellow) Pseudocoelom; (light orange line) BL of the pharynx. C. Schematic drawing of the adult hmc, left lateral view. The hmc soma is located at the dorsal side between the posterior of the terminal bulb and the anterior intestine. One long hmc process runs posteriorly at the dorsal side between the dorsal hypodermal ridge and dorsal muscle arms. Two circumferential processes travel to the ventral side and merge between the two excretory gland cell bodies. One anteriorly growing process stays in close contact with the right-side excretory gland process and terminates posterior to the loop of the gland process. Another process grows posteriorly between the ventral hypodermis and the ventral muscle arms. D. (Top) Schematic drawing of the hmc (orange) as seen from the dorsal side. (NR) Nerve ring. (Bottom panel) Corresponding epifluorescent image of the hmc in a strain expressing a GFP-tagged transgene. (Strain source: Z-W. Wang and B. Chen.) E&F. Epifluorescent images from two animals expressing the reporter gene gly18::GFP in hmc, both left lateral views. (Strain source: C.E. Warren, A. Krizus, and J.W. Dennis.) Bar, 10 μm. Post-embryonically, the hmc cell body lies dorsomedially to the terminal bulb of the pharynx in the head. It has anteriorly and posteriorly extended processes on both the dorsal and ventral margins of the body wall. A circumferential process from the soma splits at the pharynx, and these two branches grow along the sides of the terminal bulb of the pharynx, making a loop around the bulb. Ventral to the bulb, these processes first merge and then split to form a ventral anterior arm and a posterior arm. The ventral anterior process runs inside the anterior loop of the right excretory gland process and adjacent to the ventral hypodermal ridge. The ventral posterior arm runs in conjunction with ventral body wall muscle arms and the hypodermal ridge and makes gap junctions with ventral body wall muscle arms (HmcFIG 3) (see also Gap Junctions). The dorsal posterior process runs some distance adjacent to the dorsal hypodermal ridge and makes gap junctions with arms from dorsal muscles. The hmc cell body is flattened and contains a nucleus much like that of body wall muscles except for a smaller nucleolus. In the adult, this cell has very few contractile fibrils, all of which seem to lie within the circular loop of the two ventral processes that wrap around the bulb. These fibrils appear to number too few to perform any significant motor function. Unlike body wall muscles, there are no places at which this cell maintains any obvious anchorage to the cuticle. The extensive gap junctions that the hmc forms with adjacent body wall muscle arms on both the dorsal and ventral sides (White et al., 1976; J.E. Sulston, unpubl.) suggest that this might be useful in synchronizing simultaneous contractions of the dorsal and ventral head and neck muscles. Such a function has been postulated to be important in initiating and coordinating the “flipping” motions of the late embryo, before onset of the larval motor pattern (Hall and Hedgecock, 1991; E. Hedgecock and D.H. Hall, unpubl.). HmcFIG 3: Fine structure of the head mesodermal cell. The hmc and hmc processes are pseudocolored as transparent orange on transverse TEM sections. (Arrowheads) Gap junctions. Bar, 1 μm. A. Cross section of the hmc soma, which is located within the pseudocoelom ventral to the dorsal hypodermal ridge, at the level of the pharyngeal grinder. (Image source: N2U [MRC] A230-20.) B. Ventral posterior process of hmc is located in close association to the right-side excretory gland soma at this level and makes gap junctions to ventral muscle arms (arrowhead). (VNC) Ventral nerve cord. (Image source: N2U [MRC] 240-18.) C. The short, dorsal anterior process of the hmc makes a gap junction to a dorsal body wall muscle. (Ps) Pseudocoelom. (Image source: N2U [MRC] 245-3.) D. The ventral anterior process of hmc runs in close association with the right-side excretory gland process. (Arrow) Possible gap junction between the hmc and excretory gland. (Image source: N2U [MRC] 235-12.) Similar “stomatal” muscles in other nematodes have been postulated to help the digestive function of the grinder, because hmc surrounds the pharynx where the “teeth” are located (Chitwood and Chitwood, 1950). This function seems unlikely in C. elegans due to the inconsequential nature of its contractile motor elements. It is also conceivable that this cell could facilitate the function of the excretory system. The right excretory gland process remains in intimate contact with the hmc for more than 5–10 μm and may be a site for electrical coupling, although ultrastructural evidence for gap junctions between the two cells remains ambiguous to date. Because the muscle elements of the hmc are too wispy and the hmc process lies inside the gland process loop, it cannot accomplish any squeezing activity directly on the gland. Nonetheless, perhaps by synchronizing local contraction of all head muscles, this cell could facilitate excretion of granules from the excretory gland or excretion of the liquid contents of the excretory canal sinus. 2 List of Cells hmc; MSappaaa hmc homolog; MSpppaaa 3 References Chitwood, B.G. and Chitwood, M.B. 1950. An introduction to nematology. Baltimore, University Park Press. Hall, D.H. and Hedgecock, E.M. 1991. Kinesin-related gene unc-104 is required for axonal transport of synaptic vesicles in C. elegans. Cell 65: 837-847. Abstract Sulston, J.E., Schierenberg, E., White, J.G. and Thomson, J.N. 1983. The embryonic cell lineage of the nematode Caenorhabditis elegans. Dev. Biol. 100: 64-119. Article White, J.G., Southgate, E., Thomson, J.N. and Brenner, S. 1976. The structure of the ventral nerve cord of Caenorhabditis elegans. Phil. Trans. Roy. Soc. Lond. 275B: 327-348. Article White, J.G., Southgate, E., Thomson, J.N. and Brenner, S. 1986. The structure of the nervous system of the nematode Caenorhabditis elegans. Phil. Trans. Roy. Soc. Lond. 314B: 1-340. Article
This chapter should be cited as: Altun, Z.F. and Hall, D.H. 2009. Muscle system, head mesodermal cell. In WormAtlas. doi:10.3908/wormatlas.1.10 Edited for the web by Laura A. Herndon. Last revision: June 1, 2012.

©Copyright 2025 WormAtlas (Cold Spring Harbor Laboratory Press) All Rights Reserved |